#[non_exhaustive]pub enum OverlapError {
NonFinite {
operand: Operand,
},
NotClosed {
operand: Operand,
},
SelfIntersecting {
operand: Operand,
triangles: [u32; 2],
},
NoVolume {
operand: Operand,
},
}Expand description
Why no volume was bracketed.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonFinite
A coordinate is not finite.
NotClosed
The mesh is not a closed, consistently wound two-manifold without degenerate triangles, so it encloses no definite solid.
SelfIntersecting
Two triangles of the mesh intersect other than along shared vertices, so points inside it are not well defined.
NoVolume
The mesh’s enclosed volume is not certified nonzero.