#[non_exhaustive]pub enum TopologyError {
IndexOutOfRange {
triangle: usize,
vertex: u32,
vertices: usize,
},
DegenerateTriangle {
triangle: usize,
},
NonManifold {
edges: usize,
vertices: usize,
},
}Expand description
Why a mesh’s topology could not be classified.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IndexOutOfRange
A triangle names a vertex the mesh does not have.
Fields
DegenerateTriangle
A triangle repeats a vertex, so it has no edges of its own.
NonManifold
The mesh is not a two-manifold.