Function topology

pub fn topology(mesh: &TriMesh) -> Result<MeshTopology, TopologyError>
Classify every connected component of mesh.

Positions not used by any triangle are ignored.

Errors

A triangle naming a missing vertex or repeating one, and a mesh that is not a two-manifold (TopologyError::NonManifold).